summaryrefslogtreecommitdiffstats
path: root/core
diff options
context:
space:
mode:
authorDmitri Plotnikov <dplotnikov@google.com>2010-02-25 16:09:21 -0800
committerDmitri Plotnikov <dplotnikov@google.com>2010-02-25 16:09:35 -0800
commitda2572ad75c3f0815b45d00fb222b04e2c3a8d22 (patch)
tree47963b9bb41015f275f56b3a934eda10d3847ea8 /core
parent8221e323e83f631f9289296329e3d8bbb8f41e3a (diff)
downloadframeworks_base-da2572ad75c3f0815b45d00fb222b04e2c3a8d22.zip
frameworks_base-da2572ad75c3f0815b45d00fb222b04e2c3a8d22.tar.gz
frameworks_base-da2572ad75c3f0815b45d00fb222b04e2c3a8d22.tar.bz2
Renaming contact search snippet fields.
Change-Id: If27271665aedbb125072bbcd0cf375846c38cc9f
Diffstat (limited to 'core')
-rw-r--r--core/java/android/provider/ContactsContract.java23
1 files changed, 14 insertions, 9 deletions
diff --git a/core/java/android/provider/ContactsContract.java b/core/java/android/provider/ContactsContract.java
index 1163106..0b90f91 100644
--- a/core/java/android/provider/ContactsContract.java
+++ b/core/java/android/provider/ContactsContract.java
@@ -3201,28 +3201,33 @@ public final class ContactsContract {
public static final String SNIPPET_MIMETYPE = "snippet_mimetype";
/**
* The {@link CommonDataKinds.CommonColumns#DATA} field of the data row
* that was matched by the filter.
*
* @hide
*/
- public static final String SNIPPET_DATA = "snippet_data";
+ public static final String SNIPPET_DATA1 = "snippet_data1";
/**
* The {@link CommonDataKinds.CommonColumns#TYPE} field of the data row
* that was matched by the filter.
*
* @hide
*/
- public static final String SNIPPET_TYPE = "snippet_type";
+ public static final String SNIPPET_DATA2 = "snippet_data2";
/**
* The {@link CommonDataKinds.CommonColumns#LABEL} field of the data row
* that was matched by the filter.
*
* @hide
*/
- public static final String SNIPPET_LABEL = "snippet_label";
+ public static final String SNIPPET_DATA3 = "snippet_data3";
+
+ /**
+ * The {@link Data#DATA4} field of the data row that was matched by the filter.
+ *
+ * @hide
+ */
+ public static final String SNIPPET_DATA4 = "snippet_data4";
+
}
/**
@@ -3201,28 +3201,33 @@ public final class ContactsContract {
public static final String SNIPPET_MIMETYPE = "snippet_mimetype";
/**
- * The {@link CommonDataKinds.CommonColumns#DATA} field of the data row
- * that was matched by the filter.
+ * The {@link Data#DATA1} field of the data row that was matched by the filter.
*
* @hide
@@ -3201,28 +3201,33 @@ public final class ContactsContract {
/**
- * The {@link CommonDataKinds.CommonColumns#TYPE} field of the data row
- * that was matched by the filter.
+ * The {@link Data#DATA2} field of the data row that was matched by the filter.
*
* @hide
@@ -3201,28 +3201,33 @@ public final class ContactsContract {
/**
- * The {@link CommonDataKinds.CommonColumns#LABEL} field of the data row
- * that was matched by the filter.
+ * The {@link Data#DATA3} field of the data row that was matched by the filter.
*
* @hide